<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el_GR">
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/entity/RArcEntity.cpp" line="+95"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+79"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="+157"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="+152"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+81"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Κέντρο</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="-2"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="+164"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-2"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="+154"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="+156"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="+117"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="+121"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+75"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+97"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+84"/>
        <location line="+4"/>
        <location line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+90"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+88"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+78"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+108"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+78"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+75"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+90"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RToleranceEntity.cpp" line="+82"/>
        <location line="+3"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+75"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+82"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+78"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-6"/>
        <location line="+4"/>
        <location line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-5"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-16"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RToleranceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-11"/>
        <location line="+12"/>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-11"/>
        <location line="+4"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-7"/>
        <location line="+4"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-7"/>
        <location line="+5"/>
        <location line="+3"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-3"/>
        <location line="+4"/>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-15"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+3"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="-6"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-5"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RPointEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RRayEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-16"/>
        <location line="+3"/>
        <location line="+10"/>
        <location line="+4"/>
        <location filename="../src/entity/RToleranceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-8"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-6"/>
        <location line="+3"/>
        <location line="+4"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Middle</source>
        <translation>Μέσο</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <source>Radius</source>
        <translation>Ακτίνα</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="-9"/>
        <source>Start Angle</source>
        <translation>Αρχική γωνία</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>End Angle</source>
        <translation>Τελική γωνία</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+1"/>
        <source>Reversed</source>
        <translation>Αντεστραμμένο</translation>
    </message>
    <message>
        <location line="+2"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <source>Diameter</source>
        <translation>Διάμετρος</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/REllipseEntity.cpp" line="+9"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+2"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+3"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+7"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+3"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+10"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+2"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="-11"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+2"/>
        <source>Length</source>
        <translation>Μήκος</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RFaceEntity.cpp" line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location filename="../src/entity/RSplineEntity.cpp" line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <source>Total Length</source>
        <translation>Συνολικό μήκος</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sweep Angle</source>
        <translation>Γωνία σάρωσης</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+2"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+3"/>
        <source>Area</source>
        <translation>Εμβαδόν</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RCircleEntity.cpp" line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="+1"/>
        <source>Total Area</source>
        <translation>Συνολικό εμβαδόν</translation>
    </message>
    <message>
        <location filename="../src/entity/RAttributeDefinitionEntity.cpp" line="+93"/>
        <location filename="../src/entity/RAttributeEntity.cpp" line="+102"/>
        <source>Invisible</source>
        <translation>Αόρατο</translation>
    </message>
    <message>
        <location line="+2"/>
        <location filename="../src/entity/RAttributeEntity.cpp" line="-1"/>
        <source>Tag</source>
        <translation>Ετικέτα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Prompt</source>
        <translation>Προτροπή</translation>
    </message>
    <message>
        <location filename="../src/entity/RCircleEntity.cpp" line="-2"/>
        <source>Circumference</source>
        <translation>Περιφέρεια</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngular2LEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 Start</source>
        <translation>Αρχή γραμμής 1</translation>
    </message>
    <message>
        <location line="+10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 Start</source>
        <translation>Αρχή γραμμής 2</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimAngularEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 1 End</source>
        <translation>Τέλος γραμμής 1</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Line 2 End</source>
        <translation>Τέλος γραμμής 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Arc</source>
        <translation>Τόξο διάστασης</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimArcLengthEntity.cpp" line="+190"/>
        <source>Arc Symbol Type</source>
        <translation>Τύπος συμβόλου τόξου</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimDiametricEntity.cpp" line="-6"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RDimRadialEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Chord Point</source>
        <translation>Σημείο χορδής</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Far Chord Point</source>
        <translation>Μακρινό σημείο χορδής</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimLinearEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dimension Line</source>
        <translation>Γραμμή διάστασης</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 1</source>
        <translation>Σημείο επέκτασης 1</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Extension Point 2</source>
        <translation>Σημείο επέκτασης 2</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimOrdinateEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RHatchEntity.cpp" line="-11"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Αρχή</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate</source>
        <translation>Τεταγμένη</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Defining Point</source>
        <translation>Σημείο ορισμού</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Leader End Point</source>
        <translation>Τελικό σημείο γραμμής οδήγησης</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimRotatedEntity.cpp" line="+172"/>
        <source>Dimension Angle</source>
        <translation>Γωνία διάστασης</translation>
    </message>
    <message>
        <location filename="../src/entity/RDimensionEntity.cpp" line="-8"/>
        <source>Label</source>
        <translation>Ετικέτα</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Tolerance</source>
        <translation>Ανοχή</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Upper Limit</source>
        <translation>Ανώτερο όριο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Lower Limit</source>
        <translation>Κατώτερο όριο</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Definition Point</source>
        <translation>Σημείο ορισμού</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Θέση κειμένου</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Text Rotation</source>
        <translation>Περιστροφή κειμένου</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Flip First Arrow</source>
        <translation>Αναστροφή πρώτου βέλους</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Flip Second Arrow</source>
        <translation>Αναστροφή δεύτερου βέλους</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Fixed Extension Line</source>
        <translation>Σταθερή γραμμή επέκτασης</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension Line Length</source>
        <translation>Μήκος γραμμής επέκτασης</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Auto Label</source>
        <translation>Αυτόματη ετικέτα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Measured Value</source>
        <translation>Μετρημένη τιμή</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Block Name</source>
        <translation>Όνομα μπλοκ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Auto Label Position</source>
        <translation>Αυτόματη θέση ετικέτας</translation>
    </message>
    <message>
        <location filename="../src/entity/REllipseEntity.cpp" line="-17"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Major Point</source>
        <translation>Κύριο σημείο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ratio</source>
        <translation>Αναλογία</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Start Parameter</source>
        <translation>Παράμετρος έναρξης</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Parameter</source>
        <translation>Παράμετρος λήξης</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="-12"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Point</source>
        <translation>Σημείο εκκίνησης</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+4"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Point</source>
        <translation>Τελικό σημείο</translation>
    </message>
    <message>
        <location filename="../src/entity/RFaceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="-14"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 1</source>
        <translation>Σημείο 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 2</source>
        <translation>Σημείο 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 3</source>
        <translation>Σημείο 3</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RSolidEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RTraceEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Point 4</source>
        <translation>Σημείο 4</translation>
    </message>
    <message>
        <location filename="../src/entity/RHatchEntity.cpp" line="-10"/>
        <source>Solid</source>
        <translation>Συμπαγές</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Winding</source>
        <translation>Περιέλιξη</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Alpha</source>
        <translation>Άλφα</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Μοτίβο</translation>
    </message>
    <message>
        <location line="-3"/>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>From Entity</source>
        <translation>Από οντότητα</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RImageEntity.cpp" line="+14"/>
        <location filename="../src/entity/RLineEntity.cpp" line="+2"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-13"/>
        <location filename="../src/entity/RRayEntity.cpp" line="+2"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <source>Angle</source>
        <translation>Γωνία</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Scale</source>
        <translation>Κλίμακα</translation>
    </message>
    <message>
        <location line="+5"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-10"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+2"/>
        <location line="+1"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Vertex</source>
        <translation>Κορυφή</translation>
    </message>
    <message>
        <location line="+201"/>
        <source>Yes</source>
        <translation>Ναι</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>No</source>
        <translation>Όχι</translation>
    </message>
    <message>
        <location filename="../src/entity/RImageEntity.cpp" line="-18"/>
        <source>File</source>
        <translation>Αρχείο</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RPointEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Θέση</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>U</source>
        <translation>U</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width Factor</source>
        <translation>Συντελεστής πλάτους</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height Factor</source>
        <translation>Συντελεστής ύψους</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Width</source>
        <translation>Πλάτος</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Height</source>
        <translation>Ύψος</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Fade</source>
        <translation>Σβήσιμο</translation>
    </message>
    <message>
        <location filename="../src/entity/RLeaderEntity.cpp" line="-5"/>
        <source>Arrow</source>
        <translation>Βέλος</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Spline</source>
        <translation>Καμπύλη</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow Block</source>
        <translation>Μπλοκ βέλους</translation>
    </message>
    <message>
        <location filename="../src/entity/RPolylineEntity.cpp" line="-9"/>
        <source>Polyline Pattern</source>
        <translation>Μοτίβο πολυγραμμής</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Closed</source>
        <translation>Κλειστό</translation>
    </message>
    <message>
        <location line="+4"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+0"/>
        <source>Bulge</source>
        <translation>Εξόγκωση</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Start Width</source>
        <translation>Αρχικό πλάτος</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>End Width</source>
        <translation>Τελικό πλάτος</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Width</source>
        <translation>Συνολικό πλάτος</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Orientation</source>
        <translation>Προσανατολισμός</translation>
    </message>
    <message>
        <location line="+9"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Μέγεθος</translation>
    </message>
    <message>
        <location line="-2"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="-2"/>
        <source>Base Angle</source>
        <translation>Βασική γωνία</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
        <source>Size 1</source>
        <translation>Μέγεθος 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+1"/>
        <source>Size 2</source>
        <translation>Μέγεθος 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Global Z</source>
        <translation>Συνολικό Z</translation>
    </message>
    <message>
        <location filename="../src/entity/RRayEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="-11"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Base Point</source>
        <translation>Βασικό σημείο</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Second Point</source>
        <translation>Δεύτερο σημείο</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Direction Vector</source>
        <translation>Διάνυσμα κατεύθυνσης</translation>
    </message>
    <message>
        <location line="+3"/>
        <location filename="../src/entity/RXLineEntity.cpp" line="+3"/>
        <source>Fixed Angle</source>
        <translation>Σταθερή γωνία</translation>
    </message>
    <message>
        <location filename="../src/entity/RSplineEntity.cpp" line="-12"/>
        <source>Closed Periodic</source>
        <translation>Κλειστό περιοδικό</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translation>Βαθμός</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Control Point</source>
        <translation>Σημείο ελέγχου</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Fit Point</source>
        <translation>Σημείο προσαρμογής</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Knot Vector</source>
        <translation>Διάνυσμα κόμβων</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Knot</source>
        <translation>Κόμβος</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use Start Tangent</source>
        <translation>Χρήση αρχικής εφαπτομένης</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Start Tangent</source>
        <translation>Αρχική εφαπτομένη</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Use End Tangent</source>
        <translation>Χρήση τελικής εφαπτομένης</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>End Tangent</source>
        <translation>Τελική εφαπτομένη</translation>
    </message>
    <message>
        <location filename="../src/entity/RToleranceEntity.cpp" line="-5"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Location</source>
        <translation>Τοποθεσία</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Direction</source>
        <translation>Κατεύθυνση</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Κείμενο</translation>
    </message>
    <message>
        <location filename="../src/entity/RLineEntity.cpp" line="-7"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Middle Point</source>
        <translation>Μεσαίο σημείο</translation>
    </message>
    <message>
        <location filename="../src/entity/RWipeoutEntity.cpp" line="+2"/>
        <source>Frame</source>
        <translation>Πλαίσιο</translation>
    </message>
</context>
</TS>
